//
//  WriteReviewViewController.m
//  iAppsReview
//
//  Created by Kevin McNeish on 5/29/13.
//  Copyright (c) 2013 Oak Leaf Enterprises, Inc. All rights reserved.
//

#import "WriteReviewViewController.h"
#import <CoreData/CoreData.h>
#import "Review.h"
#import "ReviewEntity.h"
#import "AppCategoryEntity.h"
#import "AppCategoryViewController.h"

@interface WriteReviewViewController ()

@end

@implementation WriteReviewViewController {
	UIImage *image;
	NSURL *imageURL;
	Review *review;
	NSUInteger appCategoryID;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view.
	self.starRating.delegate = self;

	review = [[Review alloc] init];
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
	// Get the destination controller
	AppCategoryViewController *controller = segue.destinationViewController;

	// Store the AppCategoryEntity on the destination controller
	controller.appCategoryID = appCategoryID;

	// Store a reference to this view controller in the
	// delegate property of the destination view controller
	controller.delegate = self;
}

-(void)updateAppCategory:(AppCategoryEntity *)appCategoryEntity
{
	appCategoryID = appCategoryEntity.categoryID;
	self.appCategoryCell.detailTextLabel.text = appCategoryEntity.name;
	[self.tableView reloadData];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)shareReview:(id)sender {

	NSString *reviewText = self.tvwReview.text;
	NSString *appName = self.txtAppName.text;

	NSString *fullReviewText = [appName stringByAppendingFormat:@" - %@",reviewText];

	NSArray *activityItems = [NSArray arrayWithObjects:fullReviewText, nil];
	UIActivityViewController *avc = [[UIActivityViewController alloc]
									 initWithActivityItems:activityItems
									 applicationActivities:nil];
	[self presentViewController:avc animated:YES completion:nil];
}

- (IBAction)accessPhotoLibrary:(id)sender {

	// Create the image picker controller
	UIImagePickerController *imagePicker = [[UIImagePickerController alloc] init];

	// Set the image picker controller properties
	imagePicker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;

	// Store a reference to the view controller in the delegate property
	imagePicker.delegate = self;

	// Display the image picker controller
	[self presentViewController:imagePicker animated:YES completion:nil];
}

- (void)enableDisableControls {
    self.btnShare.enabled = [self isReadyToShare];
	self.btnPost.enabled = [self isReadyToShare];
}

- (IBAction)appNameChanged:(id)sender {

	[self enableDisableControls];
}

- (IBAction)postReview:(id)sender {

	// Create a new ReviewEntity and set its attributes from UI controls
	ReviewEntity *reviewEntity = (ReviewEntity *)[review createEntity];
	reviewEntity.categoryID = appCategoryID;  
	reviewEntity.userID = 1; // hard code for now
	reviewEntity.isPosted = NO;  // hard code for now
	reviewEntity.rating = self.starRating.rating;
	reviewEntity.appName = self.txtAppName.text;
	reviewEntity.comments = self.tvwReview.text;
	reviewEntity.image = [imageURL absoluteString];
	reviewEntity.userID = 1;

	// Save the ReviewEntity
	[review saveEntities];

	[self.navigationController popViewControllerAnimated:YES];
}

- (void)textViewDidChange:(UITextView *)textView {

	[self enableDisableControls];
}

- (void)starRating:(mmStarRating *)starRating ratingDidChange:(float)rating {
	
	[self enableDisableControls];
}

- (BOOL)isReadyToShare {
	// Check if either the text view or the text field is empty
	if (self.tvwReview.text.length == 0 || self.txtAppName.text.length == 0 ||
		self.starRating.rating == 0 || appCategoryID == 0) {
		// One or both of them is empty, disable the button
		return NO;
	}
	else {
		// Neither control is empty, enable the button
		return YES;
	}
}

- (void)imagePickerController:(UIImagePickerController *)
picker didFinishPickingMediaWithInfo:(NSDictionary *)info
{
	[self dismissViewControllerAnimated:YES completion:nil];

	// Get the image and store it in the image view
	image = info[UIImagePickerControllerOriginalImage];
	self.imgThumbNail.image = image;

	// Get the URL of the image
	imageURL = info[UIImagePickerControllerReferenceURL];
}

- (void)imagePickerControllerDidCancel:(UIImagePickerController *)picker
{
	[self dismissViewControllerAnimated:YES completion:nil];
}

@end
